@@ -14,13 +14,13 @@ class DistributorManager:
         self._init_internal_attributes(**kwargs)
 
     def _init_internal_attributes(self, **kwargs):
-        # Internal
-        self.log_level = logging.DEBUG if kwargs.get("log_verbose") else logging.WARNING
+        # Extract keyword args
+        log_level = logging.DEBUG if kwargs.get("log_verbose") else logging.WARNING
         # zmq
         self.context = zmq.Context()
         # Be careful when changing the init order of these channels
         self.userscript_req_channel = ServerDistributorMangerUserScriptRequestChannel(
             context=self.context,
-            logger_level=self.log_level
+            logger_level=log_level
         )
-        self.distributor_req_channel = ServerDistributorManagerRequestChannel(context=self.context)        
\ No newline at end of file
+        self.distributor_req_channel = ServerDistributorManagerRequestChannel(context=self.context)
\ No newline at end of file
